*Economics of Life Course Transitions: Housing and marriage Marriage
*Housing TVC
********Version 7.0
********Original 3/26/16
********Updated 2/11/21

set more off
use "Integrated LMPs v4.0.dta", clear

keep if round==2012

replace brthyr=2012-age if brthyr==.

*Sample/cleaning
keep if age>=15 & age<=59
keep if sex!=.
drop if brthyr==9998
drop if brthyr==.
drop if brthyr<1960
drop if brthyr>round-15


*================*
*Age at marriage
*================*

gen evrmar=.
replace evrmar=0 if marital==1 
replace evrmar=1 if marital==2 | marital==3 | marital==4 | age1stmarr!=.

*age at first marriage or age of singles
gen agemarr=age1stmarr
replace agemarr=yr1stmarr-brthyr if round==2012 & agemar==. & marital!=1
replace agemarr=age if marital==1 

*Check
tabu agemarr
replace agemarr=. if agemarr==99

gen agemar_wt=expan_indiv

drop if agemarr>age


save "Housing and Marr sample.dta", replace


********************
*Egypt
********************

*Synthetic panel

use "elmps 2012 xs v2.2 pt 1.dta", clear
rename qism kism
drop q*
*Set DK to missing
replace stat1_y=. if stat1_y==9998
replace stat2_y=. if stat2_y==9998
replace stat3_y=. if stat3_y==9998
replace stat4_y=. if stat4_y==9998

*First we're going to create a whole bunch of year-specific variables
*We're essentially making wide format data

*We're going to use a giant 'loop' 
*We want to look at a longer time span than last time, 1960-2012, so that's 53 years
forvalues i=1(1)53 {
local year=2013-`i' 


*First we want to identify which status is relevant for that year, stat_`year'
 gen stat_`year'=0 if `year'<=stat1_y
 replace stat_`year'=1 if `year'>=stat1_y & `year'<stat2_y & stat1_y <. & stat_`year'==.
 replace stat_`year'=2 if `year'>=stat2_y & `year'<stat3_y & stat2_y <. & stat_`year'==.
 replace stat_`year'=3 if `year'>=stat3_y & `year'<stat4_y & stat3_y <. & stat_`year'==.
 replace stat_`year'=4 if `year'>=stat4_y & stat4_y<. & stat_`year'==. & stat4_17==5
 *The year's status is only status 4 if status 4 has not changed

label define statfp 0 "Before Entry" 1 "First status" 2 "Second status" 3 "Third status" 4 "Fourth Status", modify
label val stat_`year' statfp
label variable stat_`year' "Status sequence for year `year'"
}

*There were a lot of changes made, since there are 15 years * 5 possible statuses (0-4)

d stat_*
*Now there's a status variable for 2012-1960

tabu stat_2000

*People are before entry, or in their first-fourth status

*Having figured out which status corresponds to which year, we can then assign 
*status/job characteristics to each year

forvalues i=1(1)53 {
local year=2013-`i' 

*We define employment status in a year as the employment status for the status of that year
 gen empst_`year'=. if stat_`year'==0
 *Missing if status is before entry
 replace empst_`year'=stat1_01 if stat_`year'==1
 *Status 1 employment status if the status in that year is status 1, etc. 
 replace empst_`year'= stat2_01 if stat_`year'==2 
 replace empst_`year'= stat3_01 if stat_`year'==3
 replace empst_`year'= stat4_01 if stat_`year'==4
 replace empst_`year'=6 if empst_`year'>=6 & empst_`year'<=7
 replace empst_`year'=7 if empst_`year'>=8 & empst_`year'<.
 replace empst_`year'=7 if empst_`year'==. & stat_`year'!=.
 *Creating employment status as non-employed if not in an employment status
label define empstatfp 1 "Waged employee" 2"Employer" 3"Self-employed" 4"Unpaid family worker" 5"Unpaid worker for others" 6 "Unemployed" 7 "OLF", modify
label val empst_`year' empstatfp
label variable empst_`year' "Employment Status in `year'"

*We do the same pattern for sector, stability, contract, and social secruity
 
 gen sectr_`year'=. if stat_`year'==0
 replace sectr_`year'=stat1_05 if stat_`year'==1
 replace sectr_`year'= stat2_05 if stat_`year'==2 
 replace sectr_`year'= stat3_05 if stat_`year'==3 
 replace sectr_`year'= stat4_05 if stat_`year'==4 
label val sectr_`year' sector
label variable sectr_`year' "Sector in `year'"

 gen contr_`year'=. if stat_`year'==0
 replace contr_`year'=stat1_08 if stat_`year'==1
 replace contr_`year'= stat2_08 if stat_`year'==2 
 replace contr_`year'= stat3_08 if stat_`year'==3
 replace contr_`year'= stat4_08 if stat_`year'==3
label variable contr_`year' "Contract in `year'"

 gen socsec_`year'=. if stat_`year'==0
 replace socsec_`year'=stat1_12 if stat_`year'==1
 replace socsec_`year'= stat2_12 if stat_`year'==2
 replace socsec_`year'= stat3_12 if stat_`year'==3
 replace socsec_`year'= stat4_12 if stat_`year'==4
label variable socsec_`year' "Soc. Sec. in `year'"

*We then define formal as either social security or contract
 gen formal_`year'=(socsec_`year'==1 | contr_`year'==1 | contr_`year'==2) 

*And we define a type of employment variable that we will use to look at employment over time
*We're going to aggregate a few categories
*Private wage work will include formal, informal, and irregular
*Non-wage work will include employers, the self-employed, and unpaid family workers

*Government
 gen typemp_`year'=1 if empst_`year'==1 & sectr_`year'>=1 & sectr_`year'<=2
 
*Private formal wage workers
 replace typemp_`year'=2 if empst_`year'==1 & (sectr_`year'>=3 & sectr_`year'<=7) & formal_`year'==1

*Private informal wage workers
 replace typemp_`year'=3 if empst_`year'==1 & (sectr_`year'>=3 & sectr_`year'<=7) & formal_`year'==0

*Non-wage
 replace typemp_`year'=4 if empst_`year'==2 | empst_`year'==3 
 
 *Unpaid family work or working for others as Unpaid Work
 replace typemp_`year'=4 if empst_`year'>=4 & empst_`year'<=5

*Unemployed
 replace typemp_`year'=5 if empst_`year'==6
 
 *OLF
 replace typemp_`year'=6 if empst_`year'==7

label define typempfp 1 "Public" 2" Private formal wage" 3 "Private informal wage" 4 "Non-wage" ///
5 "Unemployed" 6 "OLF", modify
label val typemp_`year' typempfp
label variable typemp_`year' "Type of Employment in `year'"

}

*This loop takes a minute to run all the variables and years

*Now let's keep the type of employment in each year, and age and age at (first) marriage
*so we can look at this over time
keep typemp* indid age expan gov urban kism

*Now we reshape the data
reshape long typemp_, i(indid) j(year)
*This tells STATA to take the 'wide' data we constructed and make it lon
*An observation is a person, but now it will be a person year
*The year suffix will become a variable

*This will take STATA a minute to compute

label var year "Year"
label val year 

d
*Now we have just 6 variables, but lots of observations. An observation is now a person-year

tabu year
tabu typemp_

replace indid="818"+indid

save "ELMPS TVCs Housing and Marr.dta", replace


******************************************************************************
*Birth region, birth country, birth urban/rural, in school, migration
******************************************************************************

use "elmps 2012 xs v2.2 pt 1.dta", clear

*Age left school (missing if current student)
gen age_exitsch=.
replace age_exitsch=q2107b if q2107b!=.
replace age_exitsch=q2146b if q2146b!=.
replace age_exitsch=q2137b if q2137b!=.
replace age_exitsch=q2129b if q2129b!=.
replace age_exitsch=q2120b if q2120b!=.
replace age_exitsch=q2118b if q2118b!=.
replace age_exitsch=q2113b if q2113b!=.
replace age_exitsch=q2185b if q2185b!=.

replace age_exitsch=6+yrschl if student==2 & age_exitsch==.
replace age_exitsch=. if age_exitsch==99 | age_exitsch==98
replace age_exitsch=age+1 if student==1

****Egypt 2012 Birth Geography


*Birth area: urban or rural

gen burban=q3101_4
label values burban urban
label variable burban "Area of birth urban/rural"
*Abroad
replace burban=1 if q3101_5!=.


*Birth governorate: urban or rural
gen bgov=q3101_1


*Six regions of birth

*Cairo governorate
gen     bregion=1 if q3101_1==1
*Giza governorate, specific kism #s
replace bregion=1 if q3101_1==21 & ((q3101_2>=1 & q3101_2<=7) | (q3101_2>=17 & q3101_2<=19) | q3101_2==21) 
*Kalyoubia governorate, specific kism #s
replace bregion=1 if q3101_1==14 & (q3101_2==6 | q3101_2==7 | q3101_2==12 | q3101_2==13)

*Alexandria, Port-Said, Suez governorates
replace bregion=2 if q3101_1==2 | q3101_1==3 |q3101_1==4
*Ismailia governorate, q3101_4
replace bregion=2 if q3101_1==19 & q3101_4==1

*Abroad
replace bregion=1 if q3101_5!=.

**Urban Lower Egypt
*Damietta, Dakhalia, Sharkia, Kalyoubia, Kafr-Elsheikh, Gharbia, Menoufia, and Behera governorates, q3101_4
replace bregion=3 if (q3101_1==11 | q3101_1==12 | q3101_1==13 | q3101_1==15 | q3101_1==16 | q3101_1==17 | q3101_1==18) & q3101_4==1
*Kalyoubia governorate, specific kism #s, q3101_4 
replace bregion=3 if q3101_1==14 & ((q3101_2>=1 & q3101_2<=5)| (q3101_2>=8 & q3101_2<=11) | q3101_2==14) & q3101_4==1

**Urban Upper Egypt
*Beni-Suef, Fayoum, Menia, Asyout, Suhag, Qena, Aswam, Luxur governorates, q3101_4 
replace bregion=4 if (q3101_1>=22 & q3101_1<=29) & q3101_4==1
*Giza governorate, specific kism #s, q3101_4
replace bregion=4 if q3101_1==21 & ((q3101_2>=8 & q3101_2<=16)| q3101_2==20) & q3101_4==1

**Rural Lower Egypt
*Damietta, Dakhalia, Sharkia, Kalyoubia, Kafr-Elsheikh, Gharbia, Menoufia, and Behera governorates, rural
replace bregion=5 if (q3101_1==11 | q3101_1==12 | q3101_1==13 | q3101_1==15 | q3101_1==16 | q3101_1==17 | q3101_1==18) & q3101_4==2
*Ismailia governorate, rural
replace bregion=5 if q3101_1==19 & q3101_4==2
*Kalyoubia governorate, specific kism #s, rural 
replace bregion=5 if q3101_1==14 & ((q3101_2>=1 & q3101_2<=5)| (q3101_2>=8 & q3101_2<=11) | q3101_2==14) & q3101_4==2

**Rural Upper Egypt
*Beni-Suef, Fayoum, Menia, Asyout, Suhag, Qena, Aswam, Luxur governorates, rural 
replace bregion=6 if (q3101_1>=22 & q3101_1<=29) & q3101_4==2
*Giza governorate, specific kism #s, rural
replace bregion=6 if q3101_1==21 & ((q3101_2>=8 & q3101_2<=16)| q3101_2==20) & q3101_4==2

*Frontier
replace bregion=5 if q3101_1>=31 & q3101_1<=34 & burban==2
replace bregion=3 if q3101_1>=31 & q3101_1<=34 & burban==1

replace bregion=8180+bregion
replace bgov=81800+bgov

keep indid  bregion burban age_exitsch bgov

replace indid="818"+indid

save "ELMPS 2012 region of birth.dta", replace

******************************************************************************
*Combined TVCs dataset
******************************************************************************

use "Housing and marr sample.dta", clear

merge 1:1 indid using "ELMPS 2012 region of birth.dta", update

tabu _merge
drop if _merge==2
drop _merge

keep if age>=15 & age<=59 & expan_indiv!=. & agemar_wt!=. 

recode ftempst 6=7 5=6 4=5 3=4 2=3
replace ftempst=2 if ftempst==1 & ftsec==2
replace ftempst=2 if ftempst==1 & ftsec==1
replace ftempst=7 if ftempst==1 & (ftsec!=1 & ftsec!=2 & ftsec!=3)

label define ftemp 1 "Private wage work" 2 "Public wage work" 3 "Employer" ///
4 "Self-Employed" 5 "Unpaid Family Worker" 6 "No Job" 7 "Missing/Do not know"
label values ftempst ftemp

*Keep only needed variables
keep sex agemarr age agemar_wt evrmar ////
educ1d fteducst mteducst ftempst burban bregion ///
nsisters nbrothers ftocp1d age_exitsch indid round  ///
brthyr psu bgov expan_indiv

*Variable for missing data
gen missing=0

foreach var of varlist sex agemarr age agemar_wt evrmar ////
educ1d fteducst mteducst ftempst bregion ///
nsisters nbrothers {
replace missing=1 if `var'==.
}

foreach var of varlist burban  ///
{
replace missing=1 if `var'==. 
}


foreach var of varlist ftocp1d  ///
{
replace missing=1 if `var'==. & ftempst!=5 & ftempst!=6
}

foreach var of varlist age_exitsch  ///
{
replace missing=1 if `var'==. 
}


tabu missing round

drop if missing==1

*Making TVC
stset agemarr [pw=agemar_wt], failure(evrmar=1) id(indid)

*Expanding for marriage up to age 49

compress

*Expand to allow for TVCs
expand agemarr

bysort indid: gen spell_yr = _n
label variable spell_yr "spell year identifier, by subject"

*Calendar year
gen year=brthyr+spell_yr

*Married
bysort indid: gen marr = 1 if evrmar==1 & _n==_N
label variable marr "married at this age"

tab marr if sex==1

recode marr (.=0)

*In school
gen inschool=.
replace inschool=0 if age_exitsch<spell_yr
replace inschool=1 if age_exitsch>=spell_yr
replace inschool=0 if spell_yr<=6


*Continuous cohorts

gen cont_cohort=64-age
gen cont_cosq=cont_cohort*cont_cohort/100

label var cont_cohort "64-Age"
label var cont_cosq "Square of 64-Age / 100" 

***Not working

replace ftempst=5 if ftempst==6 | ftempst==4

replace ftocp1d=99 if ftempst==5

la def Lftempst 5 "No job or DK", modify

***Collapsing categories
replace mteducst=5 if mteducst==6
replace fteducst=5 if fteducst==6

label define Lpedu 5 "Higher education", modify

la var inschool "In school"

la def Linschool 0 "Not in school" 1 "In school"
la val inschool Linschool

la def Lregion 8182 "Egypt-Alx Sz C.", modify

la def ocp1digit 6 "Skilled agricultural workers" 8 "Plant and machine operators", modify

***Merging in employment

merge 1:1 year indid using "ELMPS TVCs Housing and Marr.dta"

tabu _merge round
drop if _merge==2
drop _merge

compress

*Check of data
tabu typemp_ round, miss

drop if typemp_==.

la var typemp_ "Labor market status"

save "Housing and Marr sample TVCs.dta", replace
