********************************
*Economics of Life Course Transitions: Housing and Marriage
*Simulations do file
*Date Created: 6/16/2016
*Date revised: 2021.03.23
*v12
********************************

program drop _all

set more off, perm

********************
*Simulations
********************

*******************************************************************************
***Profile:
*******************************************************************************

*Sample of 15-59 year olds 

use "Housing and Marr merged.dta", clear

*********
****Egypt
*********
program define sims

keep in 1
keep indid round

expand 3

gen rent_all=_n-2 
gen new_rent=_n-2 

expand 2

bysort rent_all: gen b1972=_n-1
bysort rent_all: gen rent_all_int=(_n-1)*rent_all 
bysort rent_all: gen new_rent_int=(_n-1)*new_rent 


gen obs_=_n

*From 18 to 35
expand 18

bysort obs_: gen spell_yr=_n
replace spell_yr=spell_yr+17

*In school until 22
gen inschool=0
replace inschool=1 if spell_yr<=18

*Employment status if left school is informal wage work
gen typemp_=3 if inschool==0
replace typemp_=6 if inschool==1

*Secondary education
gen educ1d=4

*Father secondary, mother secondary
gen fteducst=4
gen mteducst=4

*Father professional wage worker
gen ftocp1d=2
gen ftempst=1

*Region is Greater Cairo
gen bregion=8181 if round==2012
gen burban=1

*One brother, one sister
gen nbrothers=1
gen nsisters=1

*Born 35 years before survey
gen cont_cohort=64-35
gen cont_cosq=cont_cohort^2/100


*Since 35 in survey year, year is round-45+spell_yr
gen year=round-35+spell_yr

predict double base, pr

keep base obs spell_yr 

reshape wide base, i(obs) j(spell_yr)

end


*********************Sims2 to do Egypt new_rent alone
program define sims2

keep in 1
keep indid round

expand 3

gen rent_all=0
gen new_rent=_n-2

expand 2

bysort new_rent: gen b1972=_n-1
gen rent_all_int=0
bysort new_rent: gen new_rent_int=(_n-1)*new_rent 


gen obs_=_n

*From 18 to 35
expand 18

bysort obs_: gen spell_yr=_n
replace spell_yr=spell_yr+17

*In school until 22
gen inschool=0
replace inschool=1 if spell_yr<=18

*Employment status if left school is informal wage work
gen typemp_=3 if inschool==0
replace typemp_=6 if inschool==1

*Secondary education
gen educ1d=4

*Father secondary, mother secondary
gen fteducst=4
gen mteducst=4

*Father professional wage worker
gen ftocp1d=2
gen ftempst=1

*Region is Greater Cairo
gen bregion=8181 if round==2012
gen burban=1

*One brother, one sister
gen nbrothers=1
gen nsisters=1

*Born 35 years before survey
gen cont_cohort=64-35
gen cont_cosq=cont_cohort^2/100


*Since 35 in survey year, year is round-45+spell_yr
gen year=round-35+spell_yr

predict double base, pr

keep base obs spell_yr 

reshape wide base, i(obs) j(spell_yr)

end


*********
****Egypt Female
*********
program define simsF

keep in 1
keep indid round

expand 3

gen rent_all=_n-2 
gen new_rent=_n-2 

expand 2

bysort rent_all: gen b1972=_n-1
bysort rent_all: gen rent_all_int=(_n-1)*rent_all 
bysort rent_all: gen new_rent_int=(_n-1)*new_rent 


gen obs_=_n

*From 18 to 35
expand 18

bysort obs_: gen spell_yr=_n
replace spell_yr=spell_yr+17

*In school until 22
gen inschool=0
replace inschool=1 if spell_yr<=18

*Employment status is OLF
gen typemp_=6 if inschool==0
replace typemp_=6 if inschool==1

*Secondary education
gen educ1d=4

*Father secondary, mother secondary
gen fteducst=4
gen mteducst=4

*Father professional wage worker
gen ftocp1d=2
gen ftempst=1

*Region is Greater Cairo
gen bregion=8181 if round==2012
gen burban=1

*One brother, one sister
gen nbrothers=1
gen nsisters=1

*Born 35 years before survey
gen cont_cohort=64-35
gen cont_cosq=cont_cohort^2/100


*Since 35 in survey year, year is round-45+spell_yr
gen year=round-35+spell_yr

predict double base, pr

keep base obs spell_yr 

reshape wide base, i(obs) j(spell_yr)

end


*********************Sims2 to do Egypt new_rent alone
program define sims2F

keep in 1
keep indid round

expand 3

gen rent_all=0
gen new_rent=_n-2

expand 2

bysort new_rent: gen b1972=_n-1
gen rent_all_int=0
bysort new_rent: gen new_rent_int=(_n-1)*new_rent 


gen obs_=_n

*From 18 to 35
expand 18

bysort obs_: gen spell_yr=_n
replace spell_yr=spell_yr+17

*In school until 22
gen inschool=0
replace inschool=1 if spell_yr<=18

*Employment status is OLF
gen typemp_=6 if inschool==0
replace typemp_=6 if inschool==1

*Secondary education
gen educ1d=4

*Father secondary, mother secondary
gen fteducst=4
gen mteducst=4

*Father professional wage worker
gen ftocp1d=2
gen ftempst=1

*Region is Greater Cairo
gen bregion=8181 if round==2012
gen burban=1

*One brother, one sister
gen nbrothers=1
gen nsisters=1

*Born 35 years before survey
gen cont_cohort=64-35
gen cont_cosq=cont_cohort^2/100


*Since 35 in survey year, year is round-45+spell_yr
gen year=round-35+spell_yr

predict double base, pr

keep base obs spell_yr 

reshape wide base, i(obs) j(spell_yr)

end

*************
******Run sims
*************


*Males Egypt - New_rent+Rent_all
preserve

estimates restore MEG1

replace round=2012

sims

export excel using "Graphs/MEGhaz2.xls", firstrow(variables) replace

restore

*Males Egypt - New_rent only
preserve

estimates restore MEG1

replace round=2012

sims2

export excel using "Graphs/MEGhaz.xls", firstrow(variables) replace


restore



*Females Egypt - New_rent+Rent_all
preserve

estimates restore FEG1

replace round=2012

simsF

export excel using "Graphs/FEGhaz2.xls", firstrow(variables) replace

restore

*Females Egypt - New_rent only
preserve

estimates restore FEG1

replace round=2012

sims2F

export excel using "Graphs/FEGhaz.xls", firstrow(variables) replace


restore

