********************************
*Economics of Life Course Transitions: Housing and Marriage
*Models
*Date Created: 3/26/2016
*Date revised: 7/20/16
*v10
********************************
set more off
*Sample of 15-54 year olds 

use "Housing and Marr merged.dta", clear

*Check resulting sample

*stset spell_yr [pw=agemar_wt], failure(marr==1) id(indid)

*stsum, by(round sex)

*Only want to look at when possibly marrying
keep if spell_yr>=15

***Combining <18 & >35
replace spell_yr=18 if spell_yr<18
replace spell_yr=35 if spell_yr>35 & spell_yr!=.

*Born 1972+ men 1977+ women
gen b1972=1 if (brthyr>=1972 & brthyr!=. & sex==1)
replace b1972=1 if (brthyr>=1977 & brthyr!=. & sex==2)
replace b1972=0 if (brthyr<1972 & sex==1)
replace b1972=0 if (brthyr<1977 & sex==2)


label var b1972 "M born 1972+ or F born 1977+"

***Discrete Time Proportional hazards model

*Egypt males
cloglog marr rent_all_int new_rent_int new_rent rent_all b1972 b3.typemp_ ///
i.inschool i.educ1 i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.bregion ///
i.spell_yr if sex==1 & round==2012,  eform cluster(psu) 
estimates store MEG1

*Getting the correct Ns for tables. Included after each model.
gen sample=e(sample)

preserve 
keep if sex==1 & round==2012 & sample==1
keep indid
destring indid, replace
duplicates drop
sum indid

restore

drop sample


*Egypt females
cloglog marr rent_all_int new_rent_int new_rent rent_all b1972 b3.typemp_ ///
i.inschool i.educ1 i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.bregion ///
i.spell_yr if sex==2 & round==2012,  eform cluster(psu) 

estimates store FEG1

gen sample2012F=e(sample)


*Getting the correct Ns for tables. Included after each model.
gen sampleF=e(sample)

preserve 
keep if sex==2 & round==2012 & sampleF==1
keep indid
destring indid, replace
duplicates drop
sum indid

restore


esttab MEG1 FEG1 using "HousMarrModels.csv",  order(b1972 rent_all_int new_rent_int new_rent rent_all)  cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g)) label  ///
 nobase ///
 drop(99.ftocp1d ) ///
 refcat(1.typemp_ "Labor market status (private informal omit.)" ///
 2.educ1 "Education (none omit.)" 2.mteducst "Mother's education (none omit.)" ///
 2.fteducst "Father's education (none omit.)" 1.ftempst "Father's emp. stat. (public omit.)" ///
 0.ftocp1d "Father's occup. (Manager omit.)") ///
	legend  mlabel("Men" "Women") ///
	indicate("Age in year included =*spell_yr*" "Rural residency and region dummies included =*bregion*") ///
	eform replace


	
***********************
*Sensitivity analyses
************************


***Dropping education and LM stat	

*Egypt males
cloglog marr rent_all_int new_rent_int new_rent rent_all b1972 ///
 i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.bregion ///
i.spell_yr if sex==1 & round==2012,  eform cluster(psu) 


*Egypt females
cloglog marr rent_all_int new_rent_int new_rent rent_all b1972 ///
i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.bregion ///
i.spell_yr if sex==2 & round==2012,  eform cluster(psu) 

egen gov_kism=group(gov kism)



****Kism FE (take out main effects of region and new rent, rent all)

sort indid year
set seed 278340238

*Egypt males
cloglog marr rent_all_int new_rent_int b1972 b3.typemp_ ///
i.inschool i.educ1 i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.gov_kism ///
i.spell_yr if sex==1 & round==2012,  eform cluster(psu) iter(50)


*Egypt females
cloglog marr rent_all_int new_rent_int b1972 b3.typemp_ ///
i.inschool i.educ1 i.mteducst i.fteducst b2.ftempst b1.ftocp1d ///
nbrothers nsisters cont_cohort cont_cosq ///
i.gov_kism ///
i.spell_yr if sex==2 & round==2012,  eform cluster(psu) iter(50)


