*Economics of Life Course Transitions: Housing and  Marriage
*Housing census link
********Version 14.0
********Original 3/28/16
********Updated 2021.03.23

set more off

*Note: collapsed data provided from Census to use geographic coding that matches ELMPS 2012

*********
*Egypt
*********

/*
use "ipumsi_00005.dta",replace 

*Rename for naming updates
rename eg2006a_ownershp eg06a_own
rename geo1_eg govneg
rename geo2_eg disteg
rename perwt wtper

*At household level

keep if pernum==1

*New/all

gen new_all=.
replace new_all=1 if eg06a_own==2
replace new_all=0 if eg06a_own!=2 & eg06a_own!=9 & eg06a_own!=. 

*New/rent

gen new_rent=.
replace new_rent=1 if eg06a_own==2
replace new_rent=0 if eg06a_own==1 | eg06a_own==3 | eg06a_own==7

*Rent/all

gen rent_all=.
replace rent_all=1 if eg06a_own==2 | eg06a_own==1 | eg06a_own==3 | eg06a_own==7
replace rent_all=0 if eg06a_own==4 | eg06a_own==5 | eg06a_own==6 | eg06a_own==8


tostring disteg, gen(s_disteg)
replace s_disteg="0"+s_disteg if disteg<10000

gen s_qism=substr(s_disteg,3,3)

destring s_qism, gen(kism)

rename govneg gov

collapse (mean) new_all (mean) new_rent (mean) rent_all [pw=wtper], by(kism gov) 

replace new_all=100*new_all
replace new_rent=100*new_rent
replace rent_all=100*rent_all

gen round=2012

save "EG Census Coll_renting.dta", replace
*/ 

**************
*Merging data
**************

use "Housing and Marr sample TVCs.dta", clear

merge m:1 gov kism round using "EG Census Coll_renting.dta", update 

tab round if _merge>=3 & _merge!=.
drop if _merge==2

preserve
keep if _merge==3
keep kism gov 
duplicates drop
sum
restore

drop _merge


***************
*Standardizing
***************

*Standardizing

foreach var of varlist new_rent new_all rent_all {
rename `var' nsd_`var'
gen `var'=.
}

foreach var of varlist new_rent new_all rent_all {
sum nsd_`var' if age>=15 & age<=64 & round==2012 [aw=expan_indiv]
replace `var'=(nsd_`var'-r(mean))/r(sd)
}


*Interaction between men born 1972+ (females born 1977+) and rents

gen rent_appl=0
replace rent_appl=1 if round==2012 & ((brthyr>=1972 & brthyr<=. & sex==1) | (brthyr>=1977 & brthyr<=. & sex==2))
gen new_rent_int=new_rent*rent_appl
gen new_all_int=new_all*rent_appl
gen rent_all_int=rent_all*rent_appl

label var new_rent "Percentage of new in rent (SD)"
label var new_rent_int "Percentage of new in rent and M born 1972(SD)"

label var new_all "Percentage of new in all housing (SD)"
label var new_all_int "Percentage of new in all housing and M born 1972(SD)"

label var rent_all "Percentage of rent in all housing (SD)"
label var rent_all_int "Percentage of rent in all housing and M born 1972(SD)"

save "Housing and Marr merged.dta", replace

