***************Summary Statistics 
*Lifecourse: Marriage & housing 
*Dom Rolando, Caroline Krafft
*Updated: 2021.03.23
*v22

clear
set more off

set scheme s1mono

*****Figure 1: Hazards by cohort

use "Housing and Marr sample.dta", clear

recode brthyr (1960/1965=1) (1966/1971=2) (1972/1978=3) (1979/1985=4) (1986/1997=5) , gen(bcohort)

la def Lbcohort 1 "1960-1965" 2 "1966-1971" 3 "1972-1978" 4 "1979-1985" 5 "1986-1997"
la val bcohort Lbcohort

stset agemarr [pw=agemar_wt], failure(evrmar=1) id(indid)

stsum, by(sex bcohort)

*Men
sts graph if sex==1, by(bcohort) haz width(4) kernel(triangle) title("Men") legend(title("Birth year", size(3)) row(2) label(1 "1960-1965") label(2 "1966-1971") label(3 "1972-1978") label(4 "1979-1985") label(5 "1986-1997") size(3)) tmin(15) tmax(40) plotregion(margin(zero)) xtitle("Age") ytitle("Hazard of marriage") plot1opts(lcolor(gs12) lpatt(dash)) plot2opts(lcolor(gs10) lpatt(shortdash)) plot3opts(lcolor(gs7) lpatt("l")) plot4opts(lcolor(gs4) lpatt(dash)) plot5opts(lcolor(gs1) lpatt(shortdash)) ylabel(0 "0.00" .05 "0.05" 0.1 "0.10" .15 "0.15" .2 "0.20" .25 "0.25")

graph save "Summary stats/Egypt haz marr M.gph", replace
graph export "Summary stats/Egypt haz marr M.tif", replace

*Women
sts graph if sex==2, by(bcohort) haz width(4) kernel(triangle) title("Women") legend(title("Birth year",size(3)) row(2) label(1 "1960-1965") label(2 "1966-1971") label(3 "1972-1978") label(4 "1979-1985") label(5 "1986-1997") size(3)) tmin(15) tmax(40) plotregion(margin(zero)) xtitle("Age") ytitle("Hazard of marriage") plot1opts(lcolor(gs12) lpatt(dash)) plot2opts(lcolor(gs10) lpatt(shortdash)) plot3opts(lcolor(gs7) lpatt("l")) plot4opts(lcolor(gs4) lpatt(dash)) plot5opts(lcolor(gs1) lpatt(shortdash)) ylabel(0 "0.00" .05 "0.05" 0.1 "0.10" .15 "0.15" .2 "0.20" .25 "0.25")


graph save "Summary stats/Egypt haz marr F.gph", replace
graph export "Summary stats/Egypt haz marr F.tif", replace


grc1leg "Summary stats/Egypt haz marr M.gph" "Summary stats/Egypt haz marr F.gph"


graph save "Summary stats/Egypt haz marr.gph", replace
graph export "Summary stats/Egypt haz marr.tif", replace
graph export "Summary stats/Egypt haz marr.eps", replace


****Tables

use "Integrated LMPs v4.0.dta", clear

keep if round==2012 | round==2006

keep if yr1stmarr>=round-10 & yr1stmarr!=.

 *Cleaning
foreach x of varlist furniture marrcelebcost housemarr jewelry brideprice {
replace `x'=. if `x'==99998 
}
 
gen tc=furniture+ marrcelebcost+weddprep+ housemarr+ jewelry+ brideprice
replace urban=1 if region==8181 
 
*Need spouse code mapping
*Men following wives
replace pn=spcode+.5 if sex==1
sort hhid pn

replace tc=tc[_n-1] if hhid==hhid[_n-1] & spcode==pn[_n-1] & tc==. & spcode!=.
replace housemarr=housemarr[_n-1] if hhid==hhid[_n-1] &spcode==pn[_n-1] & housemarr==. & spcode!=.
replace grshrhouse=grshrhouse[_n-1] if hhid==hhid[_n-1] &spcode==pn[_n-1] & grshrhouse==. & spcode!=.
    
  
  
*Keep men
keep if sex==1 
 
 
**********
*Table 4
********** 
 
 *Generating ratios
 gen house_wg = (housemarr/mnthwg) 
 label var house_wg "Cost of the first house/Monthly income"
 gen house_tc = housemarr/tc
  label var house_tc "Cost of the first house/Cost of marriage"
  gen house_shr_wg=(housemarr*(grshrhouse/100)/mnthwg)

  *Marriage cost tables (4)
 tabout round using ///
 "Summary stats/Summary stats table 4.xls"  ///
[aweight=expan_hh] , c(mean house_wg) ///
 f( 3c 1 1 1) clab(_ _ _) layout(cb) h3( |(Mean house_wg (5)) |)  replace sum

 tabout round using ///
 "Summary stats/Summary stats table 4.xls"  ///
[aweight=expan_hh] , c(mean house_tc) ///
 f( 3c 1 1 1) clab(_ _ _) layout(cb) h3( |(Mean house_tc (5))|)  append sum

  tabout round using ///
 "Summary stats/Summary stats table 4.xls"  ///
[aweight=expan_hh] , c(mean house_shr_wg) ///
 f( 3c 1 1 1) clab(_ _ _) layout(cb) h3( |(Mean house_shr_wg (5))|)  append sum
 
 
   tabout  round using  /// 
 "Summary stats/Summary stats Table 4n.xls" /// 
  , h3(ILMPS N  (2)) c(freq) f(2c 2c 1p) clab(_ _ _) layout(rb)  replace
  
  
  
  
 ****************************************************************** 
 *Renting and costs
 
 use "elmps 2012 xs v2.2 pt 1.dta", clear
 
*Cost of new rent

replace q7128=. if q7128<3 | q7128>5
replace q7128=3 if q7128==5

bysort q7128: sum q7121 if sex==1 & m1srt>=2012-10 & m1srt!=. & q7121<900000 & q7121!=99998 [aw=expan],detail  
 
