********************************
*Economics of Life Course Transitions: Housing and Marriage
*IPUMS comparisons do file
*Date Created: 2021.02.15
*Date revised: 2021.03.23
*v2
********************************

*********
*Table 1
*********

*Loop for size

foreach num of numlist 818 50 360 364 504 608 792 {

use "Housing data v1.dta", clear

keep if country==`num'

drop  momloc poploc age age2 sex marst perwt

********************************************************************************
*create rented: takes 1 if the unit is rented, 0 otherwise and is
*missing for NIU and unknown 
********************************************************************************
*The unit is rented for the following categories:
*Not owned (category only available for Turkey)
*Renting, not specifie
*Renting, government
*Renting, private
*Renting, collective
*Renting, joint state
*Furnished dwelling
*Renting, other
gen rented=ownershipd>=200 & ownershipd<=239
replace rented=. if ownershipd==0 | ownershipd==999 | ownershipd==.


********************************************************************************

********************************************************************************
*create nuclear: takes 1 if the individual lives in a nuclear household, 
*0 if lives in non-nuclear and missing if it cannot be considered a household
*or we don't know
********************************************************************************

****The household is considered nuclear if the existing relationships to head 
****(from the variable "related") are limited to the following
*Head
*Spouse/partner
*Child
*Biological child
*Stepchild
*Child/child-in-law (if their marital status "marstd" is anything but married/
*in union)
*Non-relative
*Visitor
*Employee
*Domestic employee
*Boarder
*Other specified non-relative
*Non-relative, n.e.c.


****The household is considered non-nuclear if in addition to the previous
****relationships any of the following relationships exist
*Child/child-in-law (if their marital status "marstd" is married/in union)
*Other relative
*Grandchild
*Grandchild or great grandchild
*Parent/parent-in-law
*Parent
*Parent-in-law
*Child-in-law
*Sibling
*Sibling-in-law
*Parent/grandparent/ascendant
*Aunt/uncle
*Nephew/niece
*Other relative, not elsewhere classified
*Other relative or non-relative

****The variable is set to missing if the following relationships exist in the HH
*Child/child-in-law and the marital status is unknown
*Group quarters
*unknown


*To create the variable nuclear, I first create the variable n that takes 1 for 
*relationships that would make the HH non-nuclear, 2 for the ambiguous 
*relationships, missing if none of these relationships exist in the HH
*The variable n2 accords the values of the variable n to all other observations
*within the HH
*The HH is then nuclear if n2==., non-nuclear if n2==1, and missing if n2==2

****Note: I don't trust the variable hhtype because in some instances where the 
****hhtype is group quarters or unclassifiable the relationships in the HH were
****limited to nuclear relationships sometimes even the most straightforward among
****those (head, spouse, child)

gen n=1 if related==3300 & inrange(marstd, 200, 220)
replace n=1 if inrange(related, 4000, 4900) | related==6000
replace n=2 if related==5600 | related==9999 | (related==3300 & marstd==999)

drop owner* related marstd



egen n2=max(n), by(country year serial)
gen nuclear=0 if n2==1
replace nuclear=1 if n2==.
replace nuclear=. if n2==2
replace nuclear=. if relate==9

label variable nuclear "Nuclear household"
label values nuclear nuclear
label define nuclear 0"non-nuclear" 1"nuclear"

drop n n2 relate

*Restrict the sample to 1 person per household
keep if pernum==1 

tabout sample [aw=hhwt] using "Summary stats/table_1.csv", ///
sum c(mean rented mean nuclear) f(2 2) style(csv) oneway append
}

*********
*Table 2
*********


use "Housing data v1.dta", clear

keep if country==818

set more off
gen agegrp=1 if inlist(age2, 4,12,13,14)
replace agegrp=2 if inlist(age2, 15,16,17,18)

label values agegrp agegrp
label define agegrp 1 "15-34" 2 "35-54" 3 "All"


gen livingarng=1 if inlist(marstd, 100, 110) & (momloc>0  | poploc>0  )
replace livingarng=2 if inlist(marstd, 210, 217) & (momloc>0  | poploc>0  )
replace livingarng=3 if inlist(marstd, 350, 400) & (momloc>0  | poploc>0  )
replace livingarng=4 if inlist(marstd, 100, 110) & momloc==0 & poploc==0
replace livingarng=5 if inlist(marstd, 210, 217) & momloc==0 & poploc==0
replace livingarng=6 if inlist(marstd, 350, 400) & momloc==0 & poploc==0

gen livwpar= (momloc>0 | poploc>0 )
gen marstagg= 1 if inlist(marstd, 100, 110)
replace marstagg=2 if inlist(marstd, 210, 217)
replace marstagg=3 if inlist(marstd, 350, 400)

label define Lmarstag 1 "never married" 2 "curr. married" 3 "prev. married", modify
label value marstagg Lmarstag


label values livingarng livingarng
label define livingarng 1 "Single living with parent" 2 "Married living with parent" ///
3 "Previously married living with parent" 4 "Single living alone" ///
5 "Married living alone" 6 "Previously married living alone"




*expand 2, gen(copy)
*replace agegrp=3 if copy==1 & agegrp!=.

**** Never married
**** Males
*Urban
tabout agegrp year  if marstagg==1 & sex==1 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) replace ///
h1("Urban Males, Never Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==1 & sex==1 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append ///
h1("Rural Males, Never Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==1 & sex==1  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Males, Never Married") h3(nil) f(2) lines(none)


********Females*******

*Urban
tabout agegrp year  if marstagg==1 & sex==2 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Urban Females, Never Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==1 & sex==2 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Rural Females, Never Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==1 & sex==2  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Females, Never Married") h3(nil) f(2) lines(none)

********Currently Married********
**** Males
*Urban
tabout agegrp year  if marstagg==2 & sex==1 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum  c(mean livwpar) style(csv) append  ///
h1("Urban Males, Curr. Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==2 & sex==1 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Rural Males, Curr. Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==2 & sex==1  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Males, Curr. Married") h3(nil) f(2) lines(none)


********Females*******

*Urban
tabout agegrp year  if marstagg==2 & sex==2 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Urban Females, Curr. Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==2 & sex==2 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Rural Females, Curr. Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==2 & sex==2  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Females, Curr. Married") h3(nil) f(2) lines(none)

********Previously married********
**** Males
*Urban
tabout agegrp year  if marstagg==3 & sex==1 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Urban Males, Prev. Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==3 & sex==1 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Rural Males, Prev. Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==3 & sex==1  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Males, Prev. Married") h3(nil) f(2) lines(none)


********Females*******

*Urban
tabout agegrp year  if marstagg==3 & sex==2 & urban==2 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Urban Females, Prev. Married") h3(nil) f(2) lines(none)

*Rural
tabout agegrp year  if marstagg==3 & sex==2 & urban==1 [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("Rural Females, Prev. Married") h3(nil) f(2) lines(none)

*All
tabout agegrp year  if marstagg==3 & sex==2  [aw=perwt]  ///
using "Summary stats/table_2.csv", sum c(mean livwpar) style(csv) append  ///
h1("All Females, Prev. Married") h3(nil) f(2) lines(none)

